/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.LogoutPrompt.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "logoutpromptadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class LogoutPromptAdaptor
 */

LogoutPromptAdaptor::LogoutPromptAdaptor(Greeter *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

LogoutPromptAdaptor::~LogoutPromptAdaptor()
{
    // destructor
}

void LogoutPromptAdaptor::promptAll()
{
    // handle method call org.kde.LogoutPrompt.promptAll
    parent()->promptAll();
}

void LogoutPromptAdaptor::promptLogout()
{
    // handle method call org.kde.LogoutPrompt.promptLogout
    parent()->promptLogout();
}

void LogoutPromptAdaptor::promptReboot()
{
    // handle method call org.kde.LogoutPrompt.promptReboot
    parent()->promptReboot();
}

void LogoutPromptAdaptor::promptShutDown()
{
    // handle method call org.kde.LogoutPrompt.promptShutDown
    parent()->promptShutDown();
}


#include "moc_logoutpromptadaptor.cpp"
